@@ -10,7 +10,7 @@ grts <- function(design, DesignID="Site", SiteBegin=1, type.frame="finite",
 # Programmers: Tony Olsen, Tom Kincaid, Don Stevens, Christian Platt,
 #              Denis White, Richard Remington
 # Date: October 8, 2002
-# Last Revised: April 30, 2015
+# Last Revised: March 8, 2016
 # Description:
 #   This function select a GRTS sample of a finite, linear, or area resource.
 #   Frame elements must be located in 1- or 2-dimensional coordinate system.
@@ -70,23 +70,26 @@ grts <- function(design, DesignID="Site", SiteBegin=1, type.frame="finite",
 #     is created from the sp object.  If src.frame equals "att.frame", then
 #     att.frame must include columns that contain x-coordinates and
 #     y-coordinates for each element in the frame.  The default is NULL.
-#   id = name of the column from att.frame that identifies the ID value for each
-#     element in the frame.  If id equals NULL, a column named "id" that
-#     contains values from one through the number of rows in att.frame is added
-#     to att.frame.  The default is NULL.
-#   xcoord = name of the column from att.frame that identifies x-coordinates
-#     when src.frame equals "att.frame".  If xcoord equals NULL, then xcoord is
-#     given the value "x".  The default is NULL.
-#   ycoord = name of the column from att.frame that identifies y-coordinates
-#     when src.frame equals "att.frame".  If ycoord equals NULL, then ycoord is
-#     given the value "y".  The default is NULL.
-#   stratum = name of the column from att.frame that identifies stratum
-#     membership for each element in the frame.  If stratum equals NULL, the
-#     design is unstratified, and a column named "stratum" (with all of its
-#     elements equal to the stratum name specified in design) is added to
-#     att.frame.  The default is NULL.
-#   mdcaty = name of the column from att.frame that identifies the unequal
-#     probability category for each element in the frame.  The default is NULL.
+#   id = a character string containing the name of the column from att.frame
+#     that identifies the ID value for each element in the frame.  If id equals
+#     NULL, a column named "id" that contains values from one through the number
+#     of rows in att.frame is added to att.frame.  The default is NULL.
+#   xcoord = a character string containing the name of the column from att.frame
+#     that identifies x-coordinates when src.frame equals "att.frame".  If
+#     xcoord equals NULL, then xcoord is given the value "x".  The default is
+#     NULL.
+#   ycoord = a character string containing the name of the column from att.frame
+#     that identifies y-coordinates when src.frame equals "att.frame".  If
+#     ycoord equals NULL, then ycoord is given the value "y".  The default is
+#     NULL.
+#   stratum = a character string containing the name of the column from
+#     att.frame that identifies stratum membership for each element in the
+#     frame.  If stratum equals NULL, the design is unstratified, and a column
+#     named "stratum" (with all of its elements equal to the stratum name
+#     specified in design) is added to att.frame.  The default is NULL.
+#   mdcaty = a character string containing the name of the column from att.frame
+#     that identifies the unequal probability category for each element in the
+#     frame.  The default is NULL.
 #   startlev = initial number of hierarchical levels to use for the GRTS grid,
 #     which must be less than or equal to maxlev (if maxlev is specified) and
 #     cannot be greater than 11.  The default is NULL.
@@ -191,10 +194,13 @@ if(src.frame == "sp.object") {
 if(src.frame == "shapefile" && is.null(att.frame))
    att.frame <- read.dbf(in.shape)
 
-# If src.frame equals "att.frame", ensure that type.frame equals "finite"
+# If src.frame equals "att.frame", ensure that type.frame equals "finite" and to
+# ensure that a data frame object is assigned to argument att.frame
 
 if(src.frame == "att.frame" && type.frame != "finite")
    stop(paste("\nThe value provided for argument type.frame must equal \"finite\" when argument \nsrc.frame equals \"att.frame\"  The value provided for argument type.frame was \n\"", type.frame, "\".", sep=""))
+if(src.frame == "att.frame" && is.null(att.frame))
+   stop(paste("\nA data frame object must be assigned to argument att.frame when argument\nsrc.frame equals \"att.frame\"."))
 
 # If id equals NULL, create ID values
 # Otherwise, ensure that the name provided for id identifies a column in
